require "httparty"
require_relative "./mailchimpv3/lists"
require_relative "./mailchimpv3/list"

module Mailchimpv3
  class API
    include HTTParty
    @auth = {}
    @headers = {'content-type': 'application/json'}
    @lists = nil
    def initialize(api_key)
      unless api_key =~ /\w+-\w{3}/
        raise StandardError
      end
      server = api_key.split('-')[1]
      self.class.base_uri "https://#{server}.api.mailchimp.com/3.0"
      @auth = {username: 'apikey', password: api_key}
    end

    def account_details
      self.class.get('/', :basic_auth => @auth).parsed_response
    end

    def lists
      Lists.new self
    end

    def list(name ="", contact={}, permission_reminder="",
                  campaign_defaults={},member_count=0, email_type_option=true)
      List.new(self, name, contact, permission_reminder,
                    campaign_defaults,member_count, email_type_option=true)
    end

    def post(url, params={})
      self.class.post(url,
        :basic_auth => @auth,
        :headers => @headers,
        :body => params.to_json
      ).parsed_response
    end
    def get(url, recieve_params="")
      self.class.get(url,
        :basic_auth => @auth,
        :query => {fields: recieve_params}
      ).parsed_response
    end
  end
end
